package MyApp::Dispatcher;
use strict;
use parent qw(Pickles::Dispatcher::Auto);

1;

__END__
